summaryrefslogtreecommitdiff
path: root/desktop/plot_style.c
diff options
context:
space:
mode:
Diffstat (limited to 'desktop/plot_style.c')
-rw-r--r--desktop/plot_style.c16
1 files changed, 15 insertions, 1 deletions
diff --git a/desktop/plot_style.c b/desktop/plot_style.c
index 8ed8fb5e6..42a4c924f 100644
--- a/desktop/plot_style.c
+++ b/desktop/plot_style.c
@@ -73,13 +73,27 @@ plot_style_t *plot_style_caret = &plot_style_caret_static;
/* html redraw widget styles */
/** plot style for widget base. */
static plot_style_t plot_style_fill_wbasec_static = {
.fill_type = PLOT_OP_TYPE_SOLID,
.fill_colour = WIDGET_BASEC,
};
plot_style_t *plot_style_fill_wbasec = &plot_style_fill_wbasec_static;
+/** plot style for dark filled widget base colour . */
+static plot_style_t plot_style_fill_darkwbasec_static = {
+ .fill_type = PLOT_OP_TYPE_SOLID,
+ .fill_colour = double_darken_colour(WIDGET_BASEC),
+};
+plot_style_t *plot_style_fill_darkwbasec = &plot_style_fill_darkwbasec_static;
+
+/** plot style for light filled widget base colour. */
+static plot_style_t plot_style_fill_lightwbasec_static = {
+ .fill_type = PLOT_OP_TYPE_SOLID,
+ .fill_colour = double_lighten_colour(WIDGET_BASEC),
+};
+plot_style_t *plot_style_fill_lightwbasec = &plot_style_fill_lightwbasec_static;
+
/** plot style for widget background. */
static plot_style_t plot_style_fill_wblobc_static = {
@@ -73,13 +73,27 @@ plot_style_t *plot_style_caret = &plot_style_caret_static;
/* html redraw widget styles */
-/** plot style for widget base. */
+/** plot style for filled widget base colour. */
static plot_style_t plot_style_fill_wbasec_static = {
.fill_type = PLOT_OP_TYPE_SOLID,